@@ -13,15 +13,16 @@ _LOGGER = logging.getLogger(__name__)
 
 async def get_status():
     amp = AmpliPi(
-        "http://amplipi.local/api",
+        "http://amplipi-dev.local:5000/api",
         10,
     )
     result = await amp.get_status()
-    source = result.sources[0]
-
-    await amp.previous_stream(source.input.split('=')[1])
-
-    _LOGGER.info(source)
+    source = result.sources.pop()
+    update = await amp.set_source(source.id, SourceUpdate(
+        mute=not source.mute,
+        vol_delta=.01
+    ))
+    _LOGGER.info(update)
     await amp.close()
 
 
